@@ -14,8 +14,8 @@
 
 
 
-#define EN_NAME "Nmap tcp connect() scan"
-#define FR_NAME "Scan Nmap tcp connect()"
+#define EN_NAME "tcp connect() scan"
+#define FR_NAME "tcp connect()"
 
 #define EN_DESC "\
 This is the Nmap TCP connect() scan.\n\n\
@@ -23,7 +23,7 @@ This scan technique is very fast and\n\
 reliable against non-firewalled hosts.\n\n\
 More information about Nmap :\n\
 http://www.insecure.org/nmap\n\n\
-Risk factor : None."
+Risk factor : None"
 
 #define FR_DESC "\
 Ce plugin est le TCP connect() scan de Nmap.\n\n\
@@ -45,7 +45,9 @@ Facteur de risque : Aucun"
 PlugExport int plugin_init(struct arglist * desc)
 {
  plug_set_id(desc, 10335);
-       
+ plug_set_version(desc, "$Revision: 1.18 $");
+   
+         
  plug_set_name(desc, FR_NAME, "francais");
  plug_set_name(desc, EN_NAME, NULL);
  
@@ -71,19 +73,22 @@ PlugExport int plugin_init(struct arglist * desc)
 PlugExport int plugin_run(struct arglist * env)
 {
   unsigned short *ports;
+
   struct arglist * globals = arg_get_value(env, "globals");
+  struct arglist * preferences = arg_get_value(env, "preferences");
   struct arglist * hostinfos = arg_get_value(env, "HOSTNAME");
-  char * port_range = arg_get_value(env, "port_range");
+  char * port_range = arg_get_value(preferences, "port_range");
   portlist openports = NULL;
   struct in_addr *p_addr;
+  int num;
   
-  if(!(ports = arg_get_value(env, "ports")))return(0);
-  arg_add_value(hostinfos, "SCAN_RANGE", ARG_PTR, sizeof(ports), ports);
+  ports = getpts(port_range, &num);
   p_addr = arg_get_value(hostinfos, "IP");
-  if(!p_addr)return(-1);
+  if( p_addr == NULL )
+  	return -1;
   tcp_scan(globals, p_addr, ports, &openports, env, hostinfos);
   plug_set_key(env, "Host/scanned", ARG_INT, (void*)1);
-  comm_send_status(globals, arg_get_value(hostinfos, "FQDN"),"portscan",  1,1);
+  comm_send_status(globals, arg_get_value(hostinfos, "NAME"),"portscan", num, num);
   return 0;
 }
 
@@ -153,7 +158,6 @@ struct timeval *nowait = malloc(sizeof(struct timeval)),
 int timeouts=0;
 int num_scanned = 0;
 int end_port = 0;
-ntp_caps* caps = arg_get_value(globals, "ntp_caps");
 j = 0;
 while(portarray[j++])end_port++;
 j = 0;
@@ -177,7 +181,7 @@ sock.sin_addr.s_addr = target->s_addr;
 sock.sin_family=AF_INET;
 FD_ZERO(fds_read);
 FD_ZERO(fds_write);
-comm_send_status(globals, arg_get_value(hostdata, "FQDN"),"portscan",  0,end_port);
+comm_send_status(globals, arg_get_value(hostdata, "NAME"),"portscan",  0,end_port);
 
 /* Initially, all of our sockets are "dead" */
 for(i = 0 ; i < MAX_SOCKETS_ALLOWED; i++) {
@@ -195,7 +199,7 @@ while(portarray[j] || retryindex >= 0 || current_out != 0) {
   for(i=current_out; i < MAX_SOCKETS_ALLOWED && (portarray[j] || retryindex >= 0); i++,
   	num_scanned++) {
   	if(num_scanned==100){
-	comm_send_status(globals, arg_get_value(hostdata, "FQDN"), 
+	comm_send_status(globals, arg_get_value(hostdata, "NAME"), 
         "portscan",
 	portarray[j]>0?portarray[j]-1:0, end_port);
         num_scanned = 0;
@@ -204,6 +208,7 @@ while(portarray[j] || retryindex >= 0 || current_out != 0) {
     if ((sockets[current_socket] = socket(AF_INET, SOCK_STREAM, IPPROTO_TCP)) == -1)
       {perror("Socket troubles"); return(NULL);}
     if (sockets[current_socket] > max) max = sockets[current_socket]; 
+    set_socket_source_addr( sockets[current_socket], 0);
     current_out++;
     unblock_socket(sockets[current_socket]);
     init_socket(sockets[current_socket]);
@@ -237,7 +242,6 @@ while(portarray[j] || retryindex >= 0 || current_out != 0) {
 	FD_SET(sockets[current_socket], fds_read);
 	break;
       default:
-	perror(""); /*falling through intentionally*/
       case ECONNREFUSED:
 	if (max == sockets[current_socket]) max--;
 	deadstack[++deadindex] = current_socket;
@@ -249,16 +253,15 @@ while(portarray[j] || retryindex >= 0 || current_out != 0) {
       }
     }
   }
-  /*  if (!portarray[j] && retryindex < 0) sleep(2); *//*If we are done, wait a second for any last packets*/
+   if (!portarray[j] && retryindex < 0) sleep(2); /*If we are done, wait a second for any last packets*/
   while((res = select(max + 1, fds_read, fds_write, NULL, 
 		      (current_out < MAX_SOCKETS_ALLOWED)?
 		      nowait : longwait)) > 0) {
-    fflush(stdout);
     for(k=0; k < MAX_SOCKETS_ALLOWED; k++)
       if (portno[k]) {
 	if (FD_ISSET(sockets[k], fds_write)
 	    && FD_ISSET(sockets[k], fds_read)) {
-	  /*printf("Socket at port %hi is selectable for r & w.", portno[k]);*/
+	  /* printf("Socket at port %hi is selectable for r & w.", portno[k]); */
 	  res = recvfrom(sockets[k], buf, 65536, 0, (struct sockaddr *)
 			 & stranger, &sockaddr_in_len);
 	  if (res >= 0) { 
@@ -275,8 +278,8 @@ while(portarray[j] || retryindex >= 0 || current_out != 0) {
 	  close(sockets[k]);
 	}
 	else if(FD_ISSET(sockets[k], fds_write)) {
-	  /*printf("Socket at port %hi is selectable for w only.VERIFYING\n",
-	    portno[k]);*/
+	   /* printf("Socket at port %hi is selectable for w only.VERIFYING\n",
+	    portno[k]); */
 	  res = send(sockets[k], buf, 0, 0);
 	  if (res < 0 ) {
 	    signal(SIGPIPE, SIG_IGN);
@@ -303,7 +306,7 @@ while(portarray[j] || retryindex >= 0 || current_out != 0) {
 	}
 	else { /* neither read nor write selected */
 	  if (time(NULL) - times[k] < 10) {
-	  /*printf("Socket at port %hi not selecting, readding.\n",portno[k]);*/
+	 /* printf("Socket at port %hi not selecting, readding.\n",portno[k]); */
 	  FD_SET(sockets[k], fds_write);
 	  FD_SET(sockets[k], fds_read);
 	  }
@@ -362,7 +365,7 @@ while(portarray[j] || retryindex >= 0 || current_out != 0) {
 
 for(k=0; k < MAX_SOCKETS_ALLOWED; k++) {
   if (portno[k]) {
-    /*printf("Almost missed port %d\n", portno[k]);*/
+   /* printf("Almost missed port %d\n", portno[k]); */
     close(sockets[k]);
   }
 }
